@@ -18,13 +18,16 @@
 #include <signal.h>
 #include <fcntl.h>
 
-/*------------------------------------------------------------------------*/
-/* Local includes                                                         */
-/*------------------------------------------------------------------------*/
+/* This code should be able to run without requiring Tcl-based XCircuit	*/
+/* but this has not been worked out, so instead it is just disabled.	*/
 
 #ifdef TCL_WRAPPER
+
+/*----------------------------------------------------------------------*/
+/* Local includes							*/
+/*----------------------------------------------------------------------*/
+
 #include <tk.h>
-#endif
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -33,7 +36,7 @@
 #include "xcircuit.h"
 
 /*----------------------------------------------------------------------*/
-/* Function prototype declarations                                      */
+/* Function prototype declarations					*/
 /*----------------------------------------------------------------------*/
 #include "prototypes.h"
 
@@ -120,7 +123,7 @@ void start_spice()
 	 /* detect that the pipe is not a terminal and switch to batch-	*/
 	 /* processing mode.						*/
 
-         execlp(SPICE_EXEC, "ngspice", "-p", NULL);
+         execlp(SPICE_EXEC, "ngspice", "-p", (char *)NULL);
 	 spiceproc = -1;
 	 Fprintf(stderr, "Exec of ngspice failed\n");
 	 return;
@@ -337,8 +340,6 @@ int exit_spice()
    return 0;
 }
 
-#ifdef TCL_WRAPPER
-
 /*------------------------------------------------------*/
 /* Spice command					*/
 /*							*/
