@@ -1563,7 +1563,7 @@ static PyObject *xc_library(PyObject *self, PyObject *args)
    }
 
    if (libnum >= xobjs.numlibs || libnum < 0)
-      libnum = createlibrary();
+      libnum = createlibrary(FALSE);
    else
       libnum += LIBRARY - 1;
 
@@ -2027,7 +2027,7 @@ void execscript()
 
    flags = 0;
 
-   xc_tilde_expand(_STR2);
+   xc_tilde_expand(_STR2, 249);
    if ((fd = fopen(_STR2, "r")) != NULL) {
       PyRun_SimpleFile(fd, _STR2);
       refresh(NULL, NULL, NULL);
@@ -2056,7 +2056,7 @@ void loadrcfile()
       
    /* try first in current directory, then look in user's home directory */
       
-   xc_tilde_expand(_STR2);
+   xc_tilde_expand(_STR2, 249);
    if ((fd = fopen(_STR2, "r")) == NULL) {
       if (userdir != NULL) {
          sprintf(_STR2, "%s/%s", userdir, USER_RC_FILE);
