@@ -408,7 +408,6 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define FILLSOLID 224  /* = 32 + 64 + 128 */
 #define OPAQUE 256
 #define BBOX 512
-#define SQUARECAP 1024
 
 /*----------------------------------------------------------------------*/
 /* Box edit styles							*/
@@ -1353,6 +1352,8 @@ typedef struct {
 /*----------------------------------------------------------------------*/
 
 typedef struct {
+   char		*libsearchpath;	 /* list of directories to search */
+   char		*filesearchpath; /* list of directories to search */
    char		*tempfile;
    char		*tempdir;
    Boolean	retain_backup;
